from aiozoom.components.base import Base


class Dashboard(Base):

    async def get_meeting_participants(self, meeting_id: str) -> dict:
        """
        Get list of participants with detail information
        """
        method = f'metrics/meetings/{meeting_id}/participants'
        return self.base_get_request(method)



import asyncio
import sys

from aiozoom.components.base import Base
from aiozoom.config import client


class Meeting(Base):

    async def create_meeting(self, email: str, body: dict) -> dict:
        """
        Create meeting for the given account email
        See docs for `body` sample
        """
        method = f'users/{email}/meetings'
        return await self.base_post_request(method, json=body)

    async def get_meeting(self, meeting_id: str) -> dict:
        method = f'meetings/{meeting_id}'
        return await self.base_get_request(method)

    async def stop_meeting(self, meeting_id: str) -> None:
        method = f'meetings/{meeting_id}'
        body = {'action': 'end'}
        res = await self.base_put_request(method, json=body)
        print(res)

    async def list_meetings(self, email: str) -> dict:
        method = f'users/{email}/meetings'
        return await self.base_get_request(method)



import os
import sys
import asyncio

from aiozoom.config import client
from aiozoom.config.auth import Configuration


class Base(Configuration):

    async def base_get_request(self, method: str, *args, **kwargs) -> dict:
        data = await client.get(method, headers=self._headers())
        return data

    async def base_post_request(self, method: str, *args, **kwargs) -> dict:
        data = await client.post(
            method, headers=self._headers(), *args, **kwargs)
        return data

    async def base_put_request(self, method: str, *args, **kwargs) -> dict:
        data = await client.put(
            method, headers=self._headers(), *args, **kwargs)
        return data

    def _headers(self) -> dict:
        return {
            'Authorization': f'Bearer {Configuration.auth_token}'
        }


# async def func():
#     ZOOM_TOKEN = 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.' \
#              'eyJhdWQiOm51bGwsImlzcyI6IlFJUEFQR2U1UWl1RWo3dnRxNHN' \
#              '3dmciLCJleHAiOjE3MzgyNjcyMDAsImlhdCI6MTU5ODAyMTA4OX0.' \
#              'a5QcuGot2zKW3jjv0Io40a6kSK4hSPhcQR6micdXxV0'
#     b = Base(ZOOM_TOKEN)
#     res = await b.base_get_request('meetings/123')
#     print(res)
#     await client.close()

# loop = asyncio.get_event_loop()
# loop.run_until_complete(func())



from setuptools import setup, find_packages

VERSION = '0.0.2' 
DESCRIPTION = 'Async library for interaction with Zoom API'
LONG_DESCRIPTION = 'Async library for interaction with Zoom API'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="aiozoom", 
        version=VERSION,
        author="Vladislav Isakov",
        author_email="vladisa88@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=['aiohttp'],
        keywords=['python', 'zoom', 'async'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)


class ConfigurationError(Exception):
    pass


class Configuration:

    auth_token: str = ''

    def __init__(self, **kwargs):
        self.assert_has_api_key()

    @staticmethod
    def configure(token: str) -> None:
        Configuration.auth_token = token

    def assert_has_api_key(self):
        if not self.auth_token:
            raise ConfigurationError('Token is required!')



import typing as tp

from aiohttp import ClientSession


BASE_URL = 'https://api.zoom.us/v2/'

class Client:

    def __init__(self, base_url: str = BASE_URL) -> None:
        self.base_url = base_url
        self.session = ClientSession()

    async def get(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
        async with self.session.get(f'{self.base_url}/{method}', *args, **kwargs) as response:
            data = await response.json()
            return data

    async def post(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
        async with self.session.post(f"{self.base_url}/{method}", *args, **kwargs) as response:
            data = await response.json()
            return data

    async def put(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
        async with self.session.put(f"{self.base_url}/{method}", *args, **kwargs) as response:
            data = await response.json()
            return data
    
    async def close(self):
        await self.session.close()

    def patch(self, method: str, *args: tp.Any, **kwargs: tp.Any) -> tp.Any:
        return self.session.patch(f"{self.base_url}/{method}", *args, **kwargs)


client = Client()
